# -*- Mode: Python -*-
# -*- coding: utf-8 -*-
# vi:si:et:sw=4:sts=4:ts=4

from codeina.ui.base import Dialog
from twisted.internet import reactor
from codeina.extern.log import log

class DownloadProgress(Dialog):

    """ Show downloading progress of files """
    
    title = ""
    # This is a static variable. Do not overwrite it under any circumpstance.
    from codeina.httpdownload import FluendoPackageDownloader
    downloader = FluendoPackageDownloader ()

    def _receive_part (self, outfile, dl, total):
        """ Callback called when a packet has been received.
        Should be used to set the progress displayer.
        """
        log.debug('codeina', 'Downloading %s : %d / %d' % (outfile, dl, total))

    def _finalized_download (self, obj):
        """ Callback called when the downloader is over.
        """
        reactor.loop.quit ()

    def _message_received (self, obj, message):
        """ Callback called when a message is received.
        check obj.status
        """
        if obj.status in ('404', '501'):
            obj.disable ()
            reactor.loop.quit ()
            self.error = (obj.status, message)
            

    def _wait_for_download (self, url):
        log.info('codeina', "Downloading %s..." % (url) )
        self.error = None
        if not self.downloader.running:
            self.downloader.start ()
        else:
            reactor.loop.run ()

    def download (self, url, outfile, postdata=None, cookies=None):
        """ Launch a download
        @url : The url of the file to download
        @outfile : The local path of the file once downloaded
        @postdata : A dictionary with POST variables.
        """
        DownloadProgress.downloader.downloadFile (url, outfile, postdata,
           self._receive_part, self._finalized_download, self._message_received, cookies=cookies)
        return self._wait_for_download (url)

